print("import: 'aem'")
import aem

print("import: 'appscript'")
import appscript

print("import: 'mactypes'")
import mactypes

print("import: 'osax'")
import osax

print("import: 'aem.ae'")
import aem.ae

